@@ -31,7 +31,8 @@ class ThresholdEvaluator(BaseEvaluator):
         """
 
 
-        if type(self.model).__name__ == "Sequential": # If model is a keras sequential model
+        if type(self.model).__name__ == "Sequential":
+            # If model is a keras sequential model
             return self.model.predict(self.X_test, batch_size=batch_size, verbose=0)
 
         else:
